<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use App\Models\Setting;
use App\Models\User;
use App\Models\Stall;
use App\Traits\ViewPathTrait;
class StallManagementController extends Controller
{
    use ViewPathTrait;
    public function index($module)
    {
        // Define the directory path
        $directoryPath = resource_path('views/admin/stall-management/' . $module);

        // Check if the directory exists, if not, create it
        if (!File::isDirectory($directoryPath)) {
            File::makeDirectory($directoryPath, 0755, true, true);
        }

        // Define the view file path
        $viewPath = $directoryPath . '/index.blade.php';

        // Check if the view file exists
        if (!File::exists($viewPath)) {
            // If the view doesn't exist, create it
            $this->createMasterIndexView($viewPath, $module);
        }
        if($module == 'number' || $module == 'categories'){
            $arr = Stall::getStalls($module);
        }else{
            $arr = Setting::getData($module);
        }
        $menuItems = json_decode(File::get(storage_path(auth()->user()->role . '_menu.json')), true);
        return view('admin.stall-management.' . $module . '.index',compact('menuItems','arr'));
    }
    public function store(Request $request){
        $model = $request->input('model');
        if($model == 'number'){
            $data = Stall::addStall($request);
            return $data;
        }else if($model == 'category'){
            $data = Stall::addCategory($request);
            return $data;
        }
        $data = Setting::insertData($model, $request);
        return $data;
    }
    public function update(Request $request){
        $model = $request->input('model');
        $id = $request->input('id');
        if($model == 'number'){
            $data = Stall::updateStall($request, $id);
        }else if($model == 'category'){
            $data = Stall::updateStallCategory($request, $id);
        }else{
            $data = Setting::updateData($model, $id, $request);
        }
        return $data;
    }
    public function destroy(Request $request)
    {
        $model = $request->input('model');
        if($model == 'Stall' || $model == 'StallCategory'){
            $id = $request->input('id');
            User::deleteById($id, $model);
        }else{
            $value = $request->input('area');
            $getRow = Setting::where('meta_key', 'stall_management_area')->first();
            $findRecord = Setting::where('meta_key', 'stall_management_area')->pluck('meta_value');
            $convertJson = json_decode($findRecord[0]);
            $array  = $convertJson->stall_area;
            $key = array_search($value, $array);
            if ($key !== false) {
                unset($array[$key]);
            }
            // Re-index the array if necessary
            $array = array_values($array);
            $newArr = [
                'stall_area' => $array
            ];
            if($getRow){
               $getRow->meta_value = json_encode($newArr);
               $getRow->save();
            }
        }
        return back()->with('error', 'Record Deleted successfully.');
    }
}
