<?php

namespace App\Http\Controllers\Exhibitor;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Furniture;
use App\Models\User;
use App\Models\Business;
use App\Models\Exhibitor;
use App\Models\Product;
use App\Models\Branding;
use App\Models\Contractor;
use App\Models\Power;
use App\Models\Media;
use App\Models\Tax;
use App\Models\Advertisement;
use App\Models\Page;
use App\Models\BadgeLimit;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Facades\File;
use App\Traits\ViewPathTrait;

class RequirementController extends Controller
{
    use ViewPathTrait;
    public function getRequirement(Request $request, $module){
        $getExhibitor = auth()->user()->id;
        $exhibitor = Exhibitor::find($getExhibitor);
        $contractors = [];
        // Define the directory path
        $directoryPath = resource_path('views/exhibitor/requirements/' . $module);

        // Check if the directory exists, if not, create it
        if (!File::isDirectory($directoryPath)) {
            File::makeDirectory($directoryPath, 0755, true, true);
        }

        // Define the view file path
        $viewPath = $directoryPath . '/index.blade.php';

        // Check if the view file exists
        if (!File::exists($viewPath)) {
            // If the view doesn't exist, create it
            $this->createMasterIndexView($viewPath, $module);
        }
        $menuItems = json_decode(File::get(storage_path(auth()->user()->role . '_menu.json')), true);
        $taxes = [];
        switch ($module) {
            case 'furniture':
                $arr = Furniture::getAllFurnitures();                              
            break;
            case 'business':
                $arr = Business::getAllBusiness();                
            break;
            case 'products':
                $arr = Product::getAllProducts();                
            break;
            case 'branding':
                $arr = Branding::getAllBranding();
            break;
            case 'contractors':
                $contractors = Contractor::getAllContractors();
                $arr = Contractor::getAllContractors();
            break;
            case 'power':
                $arr = Power::getAllPowers();
                break;
            case 'advertisement':
                $arr = Advertisement::getAllAdvertisements();
            break;
            case 'boothdesign':
                $arr = Media::getFirstBoothDesign('booth');
            break;
            case 'medias':
                $arr = Media::getFirstBoothDesign('media');
            break;
            case 'map':
                $arr = Media::getFirstBoothDesign('map');
            break;
            case 'exhibitor-content':
                $arr = Page::getFirstContent('exhibitor-dashboard-instructions');
            break;
            case 'badge-limits':
                $arr = BadgeLimit::getAllData('badges-limit');
            break;
            case 'taxes':
                $taxes = [
                    'cgst' => 'cgst',
                    'sgst' => 'sgst',
                    'igst' => 'igst',
                ];
                $arr = Tax::getAllData('taxes');
            break;
            default:
                $arr  = [];
                break;
        }
        return view('exhibitor.requirements.' . $module . '.index',compact('menuItems','arr','taxes','exhibitor','contractors'));
    }
}
