<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Models\Media;
use App\Models\Stall;
class Setting extends Model
{
    use HasFactory;
    protected $fillable = [
        'meta_key','meta_value','category'
    ];
    public static function getData($model){
        switch ($model) {
            case 'exhibition-venue':
                $data = Setting::where('meta_key', $model)->first();
                if($data){
                    return $data;
                }else{
                    $arr = [
                        'id' => 1,
                        'name' => 'Mumbai',
                        'date' => '19-01-2025 - 21-01-2025',
                        'status' => true
                    ];
                    return $arr;
                }
            break;
            case 'basic-details':
                $data = Setting::where('meta_key', $model)->get();
                if($data->isNotEmpty()){
                    return $data;
                }else{
                    $data = [];
                    return $data;
                }
            break;
            case 'website-logo':
                $arr = Media::getFirstBoothDesign('website-logo');
                return $arr;
            break;
            case 'badge-series':
                $arr = Setting::where('meta_key','badge-series')->first();
                if($arr){
                    return $arr;
                }else{
                    return [
                        'id' => 1,
                        'meta_value' => 'EXH440',
                        'status' => true
                    ];
                }
            break;
            case 'badge-image':
                $arr = Media::getFirstBoothDesign('badge');
            return $arr;
            break;
            case 'area':
                $arr = Stall::getStallAreas();
            return $arr;
            break;
            case 'mail-settings':
                $arr = Setting::where('meta_key','mail-settings')->first();
                if($arr){
                    $data = json_decode($arr->meta_value, true);
                    return $data;
                }else{
                    return [];
                }
            break;
            default:
                $arr = Setting::where('meta_key','otp-settings')->first();
                if($arr){
                    return $arr;
                }else{
                    return [];
                }
            break;
        }
    }
    public static function insertData($model, $request){
        switch ($model) {
            case 'exhibition-venue':
                $data = [
                    'venue' => $request->input('name'),
                    'date' => $request->input('date'),
                ];
            Setting::create([
                'meta_key' => $model,
                'meta_value' => json_encode($data),
                'category' => $model . '_data'
            ]);
            break;
            case 'basic-details':
                if($request->input('category') == 'facebook' || $request->input('category') == 'instagram' || $request->input('category') == 'youtube' || $request->input('category') == 'linked-in' || $request->input('category') == 'twitter'){
                    $saveCategory = 'social-profile';
                }else{
                    $saveCategory = $request->input('category');
                }
                $data = [
                    'category' => $saveCategory,
                    'info' => $request->input('meta_value'),
                ];
            Setting::create([
                'meta_key' => $model,
                'meta_value' => json_encode($data),
                'category' => $saveCategory
            ]);
            break;
            case 'website-logo' :
                $saveData = Media::boothSave($request,'website-logo');
                return $saveData;
            break;
            case 'badge-series' :
                Setting::create([
                    'meta_key' => $model,
                    'meta_value' => $request->input('series'),
                    'category' => 'frontend'
                ]);
            break;
            case 'badge' :
            $saveData = Media::boothSave($request,'badge');
            return $saveData;
            case 'otp-settings':
                $apiKey = $request->input('api_key');
                $tempalteId = $request->input('template_id');
                $templateName = $request->input('template_name');
                $senderID = $request->input('sender_id');
                $arr = [
                    'api_key' => $apiKey,
                    'template_id' => $tempalteId,
                    'template_name' => $templateName,
                    'sender_id' => $senderID,
                ];
                Setting::create([
                    'meta_key' => $model,
                    'meta_value' => json_encode($arr),
                    'category' => 'frontend'
                ]);
            break;
            case 'area' :
                $record = Setting::where('meta_key','stall_management_area')->first();
                $findData = Setting::where('meta_key','stall_management_area')->pluck('meta_value');
                if($findData && $record ){
                    $previousData = json_decode($findData[0], true);
                    if (isset($previousData['stall_area']) && is_string($previousData['stall_area'])) {
                        $previousData['stall_area'] = [$previousData['stall_area']];
                    }
                    $previousData['stall_area'][] = $request->input('area');
                    $record->meta_value = json_encode($previousData);
                    $record->save();
                }else{
                    $data = [
                        'stall_area' => [$request->input('area')],
                    ];
                    Setting::create([
                        'meta_key' => 'stall_management_area',
                        'meta_value' => json_encode($data),
                        'category' => 'backend'
                    ]);
                }
            break;
            case 'mail-settings':
                $record = Setting::where('meta_key','mail-settings')->first();
                $findData = Setting::where('meta_key','mail-settings')->pluck('meta_value');
                if($findData && $record){
                    $data = json_decode($findData[0], true);
                    foreach ($data['settings'] as $existingSetting) {
                        if ($existingSetting['type'] === $request->input('category') && $existingSetting['value']=== $request->input('email')) {
                            return back()->with('error', 'Record Already Exist.');
                        }
                    }            
                    $data['settings'][] = [
                        'type' => $request->input('category'),
                        'value' => $request->input('email'),
                    ];
                    $record->meta_value = json_encode($data);
                    $record->save();
                }else{
                    $data = [
                            'settings' => [
                                [
                                    'type' => $request->input('category'),
                                    'value' => $request->input('email'),
                                ]
                            ]
                    ];
                    Setting::create([
                        'meta_key' => 'mail-settings',
                        'meta_value' => json_encode($data),
                        'category' => 'email-management'
                    ]);
                }
            default:
            break;
        }
        return back()->with('success', 'Record Added successfully.');
    }
    public static function updateData($model, $id, $request){
        $findRecord = Setting::find($id);
        switch ($model) {
            case 'exhibition-venue':
                $data = [
                    'venue' => $request->input('name'),
                    'date' => $request->input('date'),
                ];
                $findRecord->meta_key = $model;
                $findRecord->meta_value = json_encode($data);
                $findRecord->category = $model . '_data';
            break;
            case 'basic-details':
                $data = [
                    'category' => $request->input('category'),
                    'info' => $request->input('meta_value'),
                ];
                $findRecord->meta_key = $model;
                $findRecord->meta_value = json_encode($data);
                $findRecord->category = $request->input('category');
            break;
            case 'website-logo':
                $record = Media::updateById($request,'website-logo');
                return $record;
            break;
            case 'badge-series':
                $findRecord->meta_value = $request->input('series');
            break;
            case 'badge':
                $record = Media::updateById($request,'badge');
                return $record;
            break;
            case 'otp-settings':
                $apiKey = $request->input('api_key');
                $tempalteId = $request->input('template_id');
                $templateName = $request->input('template_name');
                $senderID = $request->input('sender_id');
                $arr = [
                    'api_key' => $apiKey,
                    'template_id' => $tempalteId,
                    'template_name' => $templateName,
                    'sender_id' => $senderID,
                ];
                $findRecord->meta_value = json_encode($arr);
            break;
            case 'area':
                $getRow = Setting::where('meta_key','stall_management_area')->first();
                $getMeta = Setting::where('meta_key','stall_management_area')->pluck('meta_value');
                if($getRow && $getMeta){
                    $previousData = json_decode($getMeta[0], true);
                    $key = array_search($request->input('id'), $previousData['stall_area']);
                    if ($key !== false) {
                        // Update the value at the found index
                        $previousData['stall_area'][$key] = $request->input('area');
                    }
                    $jsonString = json_encode($previousData);
                    $getRow->meta_value = $jsonString;
                    $getRow->save();
                    return back()->with('success', 'Record Updated successfully.');
                }
            default:
            # code...
            break;
        }
        $findRecord->save();
        return back()->with('success', 'Record Updated successfully.');
    }
}
